SystemOrganization addCategory: #UIManager!
SystemOrganization addCategory: #'UIManager-Support'!

Notification subclass: #ProgressNotification
	instanceVariableNames: 'amount done extra'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'UIManager-Support'!

!ProgressNotification commentStamp: '<historical>' prior: 0!
Used to signal progress without requiring a specific receiver to notify. Caller/callee convention could be to simply count the number of signals caught or to pass more substantive information with #signal:.!

!ProgressNotification class methodsFor: 'exceptioninstantiator' stamp: 'ajh 1/22/2003 23:51'!
signal: signalerText extra: extraParam
	"TFEI - Signal the occurrence of an exceptional condition with a specified textual description."

	| ex |
	ex := self new.
	ex extraParam: extraParam.
	^ex signal: signalerText! !

!ProgressNotification methodsFor: 'accessing' stamp: 'ar 3/2/2001 20:11'!
amount
	^amount! !

!ProgressNotification methodsFor: 'accessing' stamp: 'ar 3/2/2001 20:12'!
amount: aNumber
	amount := aNumber! !

!ProgressNotification methodsFor: 'accessing' stamp: 'ar 3/2/2001 20:11'!
done
	^done! !

!ProgressNotification methodsFor: 'accessing' stamp: 'ar 3/2/2001 20:12'!
done: aNumber
	done := aNumber! !

!ProgressNotification methodsFor: 'accessing' stamp: 'ar 3/2/2001 20:12'!
extraParam
	^extra! !

!ProgressNotification methodsFor: 'accessing' stamp: 'ar 3/2/2001 20:12'!
extraParam: anObject
	extra := anObject! !

Notification subclass: #ProvideAnswerNotification
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'UIManager-Support'!

Exception subclass: #ProgressInitiationException
	instanceVariableNames: 'workBlock maxVal minVal aPoint progressTitle'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'UIManager-Support'!

!ProgressInitiationException commentStamp: '<historical>' prior: 0!
I provide a way to alter the behavior of the old-style progress notifier in String. See examples in:

ProgressInitiationException testWithout.
ProgressInitiationException testWith.
!

!ProgressInitiationException class methodsFor: 'signalling' stamp: 'ajh 1/22/2003 23:51'!
display: aString at: aPoint from: minVal to: maxVal during: workBlock

	^ self new
		display: aString at: aPoint from: minVal to: maxVal during: workBlock! !

!ProgressInitiationException class methodsFor: 'examples and tests' stamp: 'RAA 5/15/2000 15:46'!
testInnermost

	"test the progress code WITHOUT special handling"

	^'Now here''s some Real Progress'
		displayProgressAt: Sensor cursorPoint
		from: 0 
		to: 10
		during: [ :bar |
			1 to: 10 do: [ :x | 
				bar value: x. (Delay forMilliseconds: 500) wait.
				x = 5 ifTrue: [1/0].	"just to make life interesting"
			].
			'done'
		].

! !

!ProgressInitiationException class methodsFor: 'examples and tests' stamp: 'RAA 5/15/2000 12:42'!
testWith

	"test progress code WITH special handling of progress notifications"

	^[ self testWithAdditionalInfo ] 
		on: ProgressInitiationException
		do: [ :ex | 
			ex sendNotificationsTo: [ :min :max :curr |
				Transcript show: min printString,'  ',max printString,'  ',curr printString; cr
			].
		].
! !

!ProgressInitiationException class methodsFor: 'examples and tests' stamp: 'RAA 5/15/2000 12:04'!
testWithAdditionalInfo

	^{'starting'. self testWithout. 'really!!'}! !

!ProgressInitiationException class methodsFor: 'examples and tests' stamp: 'RAA 5/15/2000 15:45'!
testWithout

	"test the progress code WITHOUT special handling"

	^[self testInnermost]
		on: ZeroDivide
		do: [ :ex | ex resume]

! !

!ProgressInitiationException methodsFor: 'as yet unclassified' stamp: 'pavel.krivanek 6/17/2010 10:00'!
defaultAction

	^ UIManager default progressInitiationExceptionDefaultAction: self! !

!ProgressInitiationException methodsFor: 'as yet unclassified' stamp: 'RAA 5/15/2000 11:43'!
display: argString at: argPoint from: argMinVal to: argMaxVal during: argWorkBlock

	progressTitle := argString.
	aPoint := argPoint.
	minVal := argMinVal.
	maxVal := argMaxVal.
	workBlock := argWorkBlock.
	^self signal! !

!ProgressInitiationException methodsFor: 'as yet unclassified' stamp: 'RAA 5/15/2000 12:40'!
sendNotificationsTo: aNewBlock

	self resume: (
		workBlock value: [ :barVal |
			aNewBlock value: minVal value: maxVal value: barVal
		]
	)
! !

!ProgressInitiationException methodsFor: 'accessing' stamp: 'pavel.krivanek 9/28/2006 20:31'!
workBlock 
	
	^ workBlock! !

Object subclass: #UIManager
	instanceVariableNames: ''
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'UIManager'!

!UIManager commentStamp: 'ar 12/27/2004 08:39' prior: 0!
UIManager is a dispatcher for various UI requests.!

UIManager subclass: #DummyUIManager
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'UIManager'!

!DummyUIManager methodsFor: 'display' stamp: 'pavel.krivanek 5/31/2007 08:20'!
checkForNewDisplaySize

	Display extent = DisplayScreen actualScreenSize ifTrue: [^ self].
	DisplayScreen startUp.
! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:20'!
chooseDirectory: label from: dir

	^ nil! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:20'!
chooseFrom: aList lines: linesArray title: aString

	^ aList first! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:20'!
chooseFrom: labelList values: valueList lines: linesArray title: aString

	^ valueList first! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:23'!
confirm: queryString

	(ProvideAnswerNotification signal: queryString) ifNotNilDo: [:answer |
		^answer].

	self error: 'No user response possible'! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:23'!
confirm: aString orCancel: cancelBlock

	(ProvideAnswerNotification signal: aString) ifNotNilDo: [:answer |
		^answer == #cancel ifTrue: [cancelBlock value] ifFalse: [answer]].

	self error: 'No user response possible'! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:20'!
displayProgress: titleString at: aPoint from: minVal to: maxVal during: workBlock

	^ nil! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:20'!
edit: aText label: labelString accept: anAction

	^ nil! !

!DummyUIManager methodsFor: 'default actions' stamp: 'pavel.krivanek 5/31/2007 08:20'!
fileDoesNotExistsDefaultAction: anException
! !

!DummyUIManager methodsFor: 'default actions' stamp: 'pavel.krivanek 5/31/2007 08:20'!
fileExistsDefaultAction: anException
! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:23'!
fontFromUser: priorFont

	self error: 'No user response possible'! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:24'!
inform: aString

! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:24'!
informUserDuring: aBlock

	aBlock value: [:string | ].! !

!DummyUIManager methodsFor: 'default actions' stamp: 'pavel.krivanek 5/31/2007 08:20'!
lowSpaceWatcherDefaultAction

	Transcript show: '*** LOW SPACE ***'; cr.
! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:20'!
multiLineRequest: queryString centerAt: aPoint initialAnswer: defaultAnswer answerHeight: answerHeight! !

!DummyUIManager methodsFor: 'display' stamp: 'pavel.krivanek 5/31/2007 08:20'!
newDisplayDepthNoRestore: pixelSize

	"Change depths.  Check if there is enough space!!  , di"
	| area need |
	pixelSize = Display depth ifTrue: [^ self  "no change"].
	pixelSize abs < Display depth ifFalse:
		["Make sure there is enough space"
		area := Display boundingBox area. "pixels"

		need := (area * (pixelSize abs - Display depth) // 8)  "new bytes needed"
				+ Smalltalk lowSpaceThreshold.
		(Smalltalk garbageCollectMost <= need
			and: [Smalltalk garbageCollect <= need])
			ifTrue: [self error: 'Insufficient free space']].
	Display setExtent: Display extent depth: pixelSize.

	DisplayScreen startUp! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:26'!
progressInitiationExceptionDefaultAction: anException

	| result |

	result := anException workBlock value: [:barVal | ].

	anException resume: result! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:23'!
request: queryString initialAnswer: defaultAnswer 

	^ defaultAnswer! !

!DummyUIManager methodsFor: 'ui requests' stamp: 'pavel.krivanek 5/31/2007 08:20'!
requestPassword: queryString
	
	^ self request: queryString initialAnswer: ''! !

!DummyUIManager methodsFor: 'display' stamp: 'pavel.krivanek 5/31/2007 08:20'!
restoreDisplay! !

!DummyUIManager methodsFor: 'display' stamp: 'pavel.krivanek 5/31/2007 08:20'!
restoreDisplayAfter: aBlock

	aBlock value.
	Sensor waitButton.! !

!DummyUIManager methodsFor: 'default actions' stamp: 'pavel.krivanek 5/31/2007 08:20'!
syntaxErrorNotificationDefaultAction: anException

	Transcript show: '*** SYNTAX ERROR ***'; cr.
	Transcript show: anException; cr.
	Transcript show: (thisContext stack first: (20 min: thisContext stack size)); cr.
	anException return.! !

!DummyUIManager methodsFor: 'default actions' stamp: 'pavel.krivanek5/31/2007 08:20'!
unhandledErrorDefaultAction: anException

	Transcript show: '*** EXCEPTION ***'; cr.
	Transcript show: anException; cr.
	Transcript show: (thisContext stack first: (20 min: thisContext stack size)); cr.
	anException isResumable ifTrue: [ anException resume ]
! !

!DummyUIManager methodsFor: 'default actions' stamp: 'pavel.krivanek 5/11/2008 17:44'!
warningDefaultAction: anException

	^ self unhandledErrorDefaultAction: anException! !

!UIManager class methodsFor: 'utils' stamp: 'nice 1/5/2010 15:59'!
createPageTestWorkspace
	"Used to generate a workspace window for testing page up and page down stuff."
	"self createPageTestWorkspace"

	| numberOfLines maxStringLength minLineCounterSize lineCounterSize offsetSize stream headerConstant prevStart prevStrLen prevLineNumber |
	numberOfLines := 400.
	maxStringLength := 22.
	minLineCounterSize := 3.
	lineCounterSize := (numberOfLines log asInteger + 1) max: minLineCounterSize.
	offsetSize := 5.
	stream := ReadWriteStream on: ''.
	headerConstant := lineCounterSize + 1 + offsetSize + 1.
	prevStart := headerConstant negated.
	prevStrLen := 0.
	prevLineNumber := 0.
	numberOfLines timesRepeat: [ | pad lineNumber stringLen start charIndex log |
		stringLen := maxStringLength atRandom max: 1.
		lineNumber := prevLineNumber + 1.
		start := prevStart + prevStrLen + headerConstant + 1.
		prevStart := start.
		prevStrLen := stringLen.
		prevLineNumber := lineNumber.
		log := lineNumber log asInteger.
		pad := lineCounterSize - log - 1.
		pad timesRepeat: [stream nextPutAll: '0'].
		stream nextPutAll: lineNumber printString.
		stream space.
		log := start log asInteger.
		pad := offsetSize - log - 1.
		pad timesRepeat: [stream nextPutAll: '0'].
		stream nextPutAll: start printString.
		stream space.
		charIndex := 'a' first asInteger.
		stringLen timesRepeat: [ | char |
			char := Character value: charIndex.
			charIndex := charIndex + 1.
			stream nextPut: char].
		lineNumber = numberOfLines ifFalse: [stream cr]
		].
	self default edit: stream contents label: 'Test Data'.
! !

!UIManager class methodsFor: 'initialization' stamp: 'AlainPlantec 1/7/2010 22:51'!
default
	| mgrClass |
	^Default ifNil:[
		"Note: The way the following is phrased ensures that you can always make 'more specific' managers merely by subclassing a tool builder and implementing a more specific way of reacting to #isActiveManager. For example, a BobsUIManager can subclass MorphicUIManager and will be considered before the parent (generic MorphicUIManager)."
		mgrClass := self allSubclasses 
			detect:[:any| any isActiveManager and:[
				any subclasses noneSatisfy:[:sub| sub isActiveManager]]] ifNone:[nil].
		mgrClass ifNotNil:[mgrClass new]
	].! !

!UIManager class methodsFor: 'initialization' stamp: 'ar 12/27/2004 09:34'!
default: aUIManager
	Default := aUIManager! !

!UIManager class methodsFor: 'initialization' stamp: 'ar 2/11/2005 15:41'!
isActiveManager
	"Answer whether I should act as the active ui manager"
	^false! !

!UIManager methodsFor: 'display' stamp: 'Pavel.Krivanek 10/28/2008 11:05'!
checkForNewDisplaySize	
	
	self subclassResponsibility ! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 19:35'!
chooseDirectory
	"Let the user choose a directory"
	^self chooseDirectoryFrom: FileDirectory default! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 19:36'!
chooseDirectory: label
	"Let the user choose a directory"
	^self chooseDirectory: label from: FileDirectory default! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 19:36'!
chooseDirectory: label from: dir
	"Let the user choose a directory"
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 19:36'!
chooseDirectoryFrom: dir
	"Let the user choose a directory"
	^self chooseDirectory: nil from: dir! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/17/2005 00:26'!
chooseFileMatching: patterns
	"Let the user choose a file matching the given patterns"
	^self chooseFileMatching: patterns label: nil! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/17/2005 00:26'!
chooseFileMatching: patterns label: labelString
	"Let the user choose a file matching the given patterns"
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 10:44'!
chooseFrom: aList
	"Choose an item from the given list. Answer the index of the selected item."
	^self chooseFrom: aList lines: #()! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 10:45'!
chooseFrom: aList lines: linesArray
	"Choose an item from the given list. Answer the index of the selected item."
	^self chooseFrom: aList lines: linesArray title: ''! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 09:37'!
chooseFrom: aList lines: linesArray title: aString
	"Choose an item from the given list. Answer the index of the selected item."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 10:44'!
chooseFrom: aList title: aString
	"Choose an item from the given list. Answer the index of the selected item."
	^self chooseFrom: aList lines: #() title: aString! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/15/2005 23:42'!
chooseFrom: labelList values: valueList
	"Choose an item from the given list. Answer the selected item."
	^self chooseFrom: labelList values: valueList lines: #()! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/15/2005 23:43'!
chooseFrom: labelList values: valueList lines: linesArray
	"Choose an item from the given list. Answer the selected item."
	^self chooseFrom: labelList values: valueList lines: linesArray title: ''! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/15/2005 23:43'!
chooseFrom: labelList values: valueList lines: linesArray title: aString
	"Choose an item from the given list. Answer the selected item."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/15/2005 23:43'!
chooseFrom: labelList values: valueList title: aString
	"Choose an item from the given list. Answer the selected item."
	^self chooseFrom: labelList values: valueList lines: #() title: aString! !

!UIManager methodsFor: 'ui requests' stamp: 'EstebanLorenzano 11/21/2009 17:01'!
chooseOrRequestFrom: aList title: aString
	"Choose an item from the given list. Answer the index of the selected item."
	^self chooseOrRequestFrom: aList lines: #() title: aString! !

!UIManager methodsFor: 'ui requests' stamp: 'EstebanLorenzano 11/21/2009 10:48'!
chooseOrRequestFrom: labelList values: valueList lines: linesArray title: aString
	self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 08:39'!
confirm: queryString
	"Put up a yes/no menu with caption queryString. Answer true if the 
	response is yes, false if no. This is a modal question--the user must 
	respond yes or no."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'jrd 5/12/2009 18:02'!
confirm: queryString label: titleString
	
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 09:49'!
confirm: aString orCancel: cancelBlock
	"Put up a yes/no/cancel menu with caption aString. Answer true if  
	the response is yes, false if no. If cancel is chosen, evaluate  
	cancelBlock. This is a modal question--the user must respond yes or no."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'dc 1/10/2008 08:09'!
confirm: queryString trueChoice: trueChoice falseChoice: falseChoice 
	"Put up a yes/no menu with caption queryString. The actual wording for the two choices will be as provided in the trueChoice and falseChoice parameters. Answer true if the response is the true-choice, false if it's the false-choice.
	This is a modal question -- the user must respond one way or the other."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'GaryChambers 8/23/2010 12:11'!
confirm: queryString trueChoice: trueChoice falseChoice: falseChoice cancelChoice: cancelChoice default: aSymbol
	"Put up a yes/no/cancel menu with caption queryString. The actual wording for the choices will be as provided in the trueChoice, falseChoice and cancelChoice parameters.
	Default should be one of #yes, #no or #cancel to set the default button.
	Answer true if the response is the true-choice, false if it's the false-choice, nil if the cancelChoice.
	This is a modal question -- the user must respond."
	
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 2/28/2005 17:10'!
displayProgress: titleString at: aPoint from: minVal to: maxVal during: workBlock
	"Display titleString as a caption over a progress bar while workBlock is evaluated."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 18:56'!
edit: aText
	"Open an editor on the given string/text"
	^self edit: aText label: nil! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 18:56'!
edit: aText label: labelString
	"Open an editor on the given string/text"
	^self edit: aText label: labelString accept: nil! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 18:56'!
edit: aText label: labelString accept: anAction
	"Open an editor on the given string/text"
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'AlainPlantec 4/15/2010 10:39'!
enterOrRequestFrom: aList title: aString
	"Choose an item from the given list. Answer the index of the selected item."
	^self enterOrRequestFrom: aList lines: #() title: aString! !

!UIManager methodsFor: 'default actions' stamp: 'pavel.krivanek 6/17/2010 09:23'!
fileDoesNotExistsDefaultAction: anException

	^ self subclassResponsibility ! !

!UIManager methodsFor: 'default actions' stamp: 'pavel.krivanek 6/17/2010 09:19'!
fileExistsDefaultAction: anException

	^ self subclassResponsibility ! !

!UIManager methodsFor: 'ui requests' stamp: 'Pavel.Krivanek 10/28/2008 10:45'!
fontFromUser: priorFont	
	
	self subclassResponsibility! !

!UIManager methodsFor: 'bitBlt' stamp: 'Pavel.Krivanek 10/28/2008 11:02'!
grafPort	
	
	^ Display defaultBitBltClass current! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 08:46'!
inform: aString
	"Display a message for the user to read and then dismiss"
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 2/28/2005 20:40'!
informUser: aString during: aBlock
	"Display a message above (or below if insufficient room) the cursor 
	during execution of the given block.
		UIManager default informUser: 'Just a sec!!' during: [(Delay forSeconds: 1) wait].
	"
	^self informUserDuring:[:bar| bar value: aString. aBlock value].! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 2/28/2005 17:06'!
informUserDuring: aBlock
	"Display a message above (or below if insufficient room) the cursor 
	during execution of the given block.
		UIManager default informUserDuring:[:bar|
			#(one two three) do:[:info|
				bar value: info.
				(Delay forSeconds: 1) wait]]"
	^self subclassResponsibility! !

!UIManager methodsFor: 'settings' stamp: 'Pavel.Krivanek 10/28/2008 10:49'!
interactiveParserFor: requestor	
	
	^ false! !

!UIManager methodsFor: 'default actions' stamp: 'pavel.krivanek 6/17/2010 09:27'!
lowSpaceWatcherDefaultAction: preemptedProcess! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 2/28/2005 17:05'!
multiLineRequest: queryString centerAt: aPoint initialAnswer: defaultAnswer answerHeight: answerHeight
	"Create a multi-line instance of me whose question is queryString with
	the given initial answer. Invoke it centered at the given point, and
	answer the string the user accepts.  Answer nil if the user cancels.  An
	empty string returned means that the ussr cleared the editing area and
	then hit 'accept'.  Because multiple lines are invited, we ask that the user
	use the ENTER key, or (in morphic anyway) hit the 'accept' button, to 
	submit; that way, the return key can be typed to move to the next line."
	^self subclassResponsibility! !

!UIManager methodsFor: 'display' stamp: 'Pavel.Krivanek 10/28/2008 11:05'!
newDisplayDepthNoRestore: pixelSize	
	
	self subclassResponsibility ! !

!UIManager methodsFor: 'events' stamp: 'Pavel.Krivanek 10/28/2008 11:01'!
onDebug: process context: context title: title full: bool! !

!UIManager methodsFor: 'events' stamp: 'Pavel.Krivanek 10/28/2008 11:22'!
onEventSensorStartup: anEventSensor

! !

!UIManager methodsFor: 'default actions' stamp: 'pavel.krivanek 6/17/2010 09:24'!
onFontsChanged

	! !

!UIManager methodsFor: 'events' stamp: 'Pavel.Krivanek 10/28/2008 11:01'!
onPrimitiveError: aString	! !

!UIManager methodsFor: 'events' stamp: 'Pavel.Krivanek 10/28/2008 11:01'!
onSnapshot	! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 08:41'!
request: queryString 
	"Create an instance of me whose question is queryString. Invoke it 
	centered at the cursor, and answer the string the user accepts. Answer 
	the empty string if the user cancels."
	^self request: queryString initialAnswer: ''! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 08:41'!
request: queryString initialAnswer: defaultAnswer 
	"Create an instance of me whose question is queryString with the given 
	initial answer. Invoke it centered at the given point, and answer the 
	string the user accepts. Answer the empty string if the user cancels."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'StephaneDucasse 2/13/2010 11:22'!
request: queryString initialAnswer: defaultAnswer centerAt: aPoint
	"Create an instance of me whose question is queryString with the given
	initial answer. Invoke it centered at the given point, and answer the
	string the user accepts. Answer the empty string if the user cancels."

	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'AlainPlantec 10/19/2010 16:30'!
request: aStringOrText initialAnswer: defaultAnswer title: aTitle
	"Create an instance of me whose question is queryString with the given 
	initial answer. Invoke it centered at the given point, and answer the 
	string the user accepts. Answer the empty string if the user cancels."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 08:47'!
requestPassword: queryString
	"Create an instance of me whose question is queryString. Invoke it centered
	at the cursor, and answer the string the user accepts. Answer the empty 
	string if the user cancels."
	^self subclassResponsibility! !

!UIManager methodsFor: 'display' stamp: 'Pavel.Krivanek 10/28/2008 11:05'!
restoreDisplay	
	
	self subclassResponsibility ! !

!UIManager methodsFor: 'display' stamp: 'Pavel.Krivanek 10/28/2008 11:05'!
restoreDisplayAfter: aBlock	
	
	self subclassResponsibility ! !

!UIManager methodsFor: 'default actions' stamp: 'pavel.krivanek 6/17/2010 09:25'!
syntaxErrorNotificationDefaultAction: anException

	^ self subclassResponsibility ! !

!String methodsFor: '*UIManager-Support' stamp: 'yo 11/3/2004 19:24'!
displayProgressAt: aPoint from: minVal to: maxVal during: workBlock 
	"Display this string as a caption over a progress bar while workBlock is evaluated.

EXAMPLE (Select next 6 lines and Do It)
'Now here''s some Real Progress'
	displayProgressAt: Sensor cursorPoint
	from: 0 to: 10
	during: [:bar |
	1 to: 10 do: [:x | bar value: x.
			(Delay forMilliseconds: 500) wait]].

HOW IT WORKS (Try this in any other language :-)
Since your code (the last 2 lines in the above example) is in a block,
this method gets control to display its heading before, and clean up 
the screen after, its execution.
The key, though, is that the block is supplied with an argument,
named 'bar' in the example, which will update the bar image every 
it is sent the message value: x, where x is in the from:to: range.
"
	^ProgressInitiationException 
		display: self
		at: aPoint 
		from: minVal 
		to: maxVal 
		during: workBlock! !
